Skip to contents

The function appends extra information like gene names or protein desriptions to the protein groups: as additional columns to the nested proteins data frame and as aggregated values (semicolon separated for strings) to the outer protgroups data frame for the columns listed in aggregates_cols.

Usage

append_protein_groups_info(
  protgroups,
  proteins_info = NULL,
  peptides_info = NULL,
  protein_col = "protein",
  protein_rank_col = NULL,
  aggregate_cols = NULL
)

Arguments

protgroups

A nested protein groups data frame produced by assemble_protein_groups().

proteins_info

An optional data frame with additional proteins information.

peptides_info

An optional data frame with additional peptides information.

protein_col

Name for the protein accession column.

protein_rank_col

A column of the proteins_info table that is used for sorting proteins when aggregating values. By default, the uniprot_entry_rank column is used if present, otherwise the protein_col is used.

aggregate_cols

A vector of columns from proteins_info to include. in the main protgroups data frame. By default, all columns are used.

Value

The protgroups data frame with additional information.