Skip to contents

The main function is assemble_protein_groups, which takes a peptide-to-protein mapping and assembles protein groups based on shared peptides. Default rule for merging proteins into a single group

Usage

default_protein_grouping(
  pepgroup_to_pepgroup,
  nspec_peptides = 1L,
  rspec_peptides = NA_real_
)

Arguments

pepgroup_to_pepgroup

a data frame of peptide-sharing protein group candidates

nspec_peptides

Number of specific peptides threshold.

rspec_peptides

Fraction of specific peptides threshold.

Value

filtered pepgroup_to_pepgroup frame with pairs of protein group candidates to merge