Assign a rank to each UniProt entry based on how complete is its information. Used to sort proteins within a protein group.
Arguments
- proteins
A protein data frame produced by
parse_uniprot_fasta()
Assign a rank to each UniProt entry based on how complete is its information. Used to sort proteins within a protein group.
A protein data frame produced by parse_uniprot_fasta()