Append extra information to a protein groups frame
Source:R/protgroup_assembly.R
append_protein_groups_info.RdThe function appends extra information like gene names or
protein desriptions to the protein groups: as additional
columns to the nested proteins data frame and as aggregated
values (semicolon separated for strings) to the outer
protgroups data frame for the columns listed in aggregates_cols.
Usage
append_protein_groups_info(
protgroups,
proteins_info = NULL,
peptides_info = NULL,
protein_col = "protein",
protein_rank_col = NULL,
aggregate_cols = NULL
)Arguments
- protgroups
A nested protein groups data frame produced by
assemble_protein_groups().- proteins_info
An optional data frame with additional proteins information.
- peptides_info
An optional data frame with additional peptides information.
- protein_col
Name for the protein accession column.
- protein_rank_col
A column of the
proteins_infotable that is used for sorting proteins when aggregating values. By default, theuniprot_entry_rankcolumn is used if present, otherwise theprotein_colis used.- aggregate_cols
A vector of columns from
proteins_infoto include. in the mainprotgroupsdata frame. By default, all columns are used.