Functions for protein group inference, inspired by the concepts from "MaxQuant's post-computational razor: a massively parallel graphical model for post-processing proteomics data" by K. S. Rudolph et al.
Source:R/protgroup_assembly.R
default_protein_grouping.RdThe main function is assemble_protein_groups, which takes a peptide-to-protein
mapping and assembles protein groups based on shared peptides.
Default rule for merging proteins into a single group
Usage
default_protein_grouping(
pepgroup_to_pepgroup,
nspec_peptides = 1L,
rspec_peptides = NA_real_
)