Applies Seer brand colors to ggplot2 color aesthetics. Uses the primary Seer colors: teal, purple, blue, cyan, melon, taupe.
Usage
scale_colour_seer(..., aesthetics = "colour", palette = seer_ggplot_colors)
scale_color_seer(..., aesthetics = "colour", palette = seer_ggplot_colors)Arguments
- ...
Additional arguments passed to
ggplot2::discrete_scale().- aesthetics
Character string or vector of character strings listing the aesthetics to which this scale should be applied. Defaults to "colour".
- palette
A character vector of color names from
seer_paletteto use. Defaults to the primary Seer colors.
Examples
if (requireNamespace("ggplot2", quietly = TRUE)) {
p <- ggplot2::ggplot(ggplot2::mpg, ggplot2::aes(displ, hwy, color = class)) +
ggplot2::geom_point()
p + scale_colour_seer()
# Using a subset of Seer colors
p + scale_colour_seer(palette = c("purple", "melon", "teal"))
}
#> Warning: This manual palette can handle a maximum of 3 values. You have supplied 7
#> Warning: Removed 141 rows containing missing values or values outside the scale range
#> (`geom_point()`).